Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(127)

Unified Diff: src/core/SkNormalSource.h

Issue 2237963002: LightingShader and NormalSource comment and style fixes (Closed) Base URL: https://skia.googlesource.com/skia@master
Patch Set: Addressed patch 1 comment Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/core/SkNormalMapSource.cpp ('k') | src/gpu/glsl/GrGLSLProgramBuilder.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/core/SkNormalSource.h
diff --git a/src/core/SkNormalSource.h b/src/core/SkNormalSource.h
index 4b09d0b41188531be6c73dce235726bdba82a048..84aa9c44663ca49dcf0c2fb0764122a09a73d225 100644
--- a/src/core/SkNormalSource.h
+++ b/src/core/SkNormalSource.h
@@ -68,7 +68,7 @@ public:
*/
static sk_sp<SkNormalSource> MakeFromNormalMap(sk_sp<SkShader> map, const SkMatrix& ctm);
- /** Returns a normal source that provides straight-up normals only (0, 0, 1).
+ /** Returns a normal source that provides straight-up normals only <0, 0, 1>.
*/
static sk_sp<SkNormalSource> MakeFlat();
@@ -108,8 +108,10 @@ public:
*/
kRoundedIn
};
- /** Returns a normal source that generates a bevel for the given shape. UNIMPLEMENTED: Will
- return straight-up normals only.
+
+ /** Returns a normal source that generates a bevel for the shape being drawn. Currently this is
+ not implemented on CPU rendering. On GPU this currently only works for anti-aliased circles
+ and rectangles.
@param type the type of bevel to add.
@param width the width of the bevel, in source space. Must be positive.
« no previous file with comments | « src/core/SkNormalMapSource.cpp ('k') | src/gpu/glsl/GrGLSLProgramBuilder.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698